@@ -27,12 +27,13 @@ cleanUp ()
      SED=gsed
    fi
 
-
    $SED                                                   \
        -e "s|\o033|\\\033|g"                              \
        -e "s|[\\]27|\\\033|g"                             \
        -e "s|='\\\\033|='\\\\\\\\033|g"                   \
+       -e "s|^User shell.*||"                             \
        -e "s|\@git\@|$gitV|g"                             \
+       -e "s|$PATH_to_SHA1/$SHA1SUM|PATH_to_HASHSUM|g"    \
        -e "s|/usr/.*/sha1sum|PATH_to_HASHSUM|g"           \
        -e "s|/bin/.*/sha1sum|PATH_to_HASHSUM|g"           \
        -e "s|:$PATH_to_LUA\([:;]\)|\1|g"                  \
@@ -56,7 +57,11 @@ cleanUp ()
        -e "s|;$PATH_to_SHA1:[0-9];|;|g"                   \
        -e "s| $PATH_to_SHA1||g"                           \
        -e "s|\\\;$PATH_to_SHA1:[0-9]\\\;|\\\;|g"          \
-       -e "s|^Lmod version.*||g"                          \
+       -e "s|:$PATH_TO_SED\([:;]\)|\1|g"                  \
+       -e "s|;$PATH_TO_SED:[0-9];|;|g"                    \
+       -e "s| $PATH_TO_SED||g"                            \
+       -e "s|\\\;$PATH_TO_SED:[0-9]\\\;|\\\;|g"           \
+       -e "s|^ *Lmod version.*||g"                        \
        -e "s|^LMOD_LD_PRELOAD.*||g"                       \
        -e "s|^LuaFileSystem version.*||g"                 \
        -e "s|^Lua Version.*||g"                           \
@@ -94,6 +99,10 @@ cleanUp ()
        -e "s|.*_AST_FEATURES.*||"                         \
        -e "/^Changes from Default Configuration.*/d"      \
        -e "/^Name * Default *Value.*/d"                   \
+       -e "/^Name * Where Set *Default *Value.*/d"        \
+       -e "/^Where Set.*/d"                               \
+       -e "/^ *lmod_cfg: l.*/d"                           \
+       -e "/^ *Other: Set.*/d"                            \
        -e "/^LFS_VERSION.*/d"                             \
        -e "/^Active lua-term.*/d"                         \
        -e "/Rebuilding cache.*done/d"                     \
@@ -141,7 +150,7 @@ runMe ()
 }
 runLmod ()
 {
-   runBase $LUA_EXEC $projectDir/src/lmod.in.lua bash --regression_testing "$@"
+   runBase $LUA_EXEC $projectDir/src/lmod.in.lua shell --regression_testing "$@"
    eval "`cat _stdout.$NUM`"
 }
 
@@ -264,19 +273,22 @@ initStdEnvVars()
   unset TERM
   unset _LMFILES_
   unset LMOD_SET_NOGLOB
+  unset LMOD_SYSTEM_DEFAULT_MODULES
 
   PATH_to_LUA=`findcmd --pathOnly lua`
   PATH_to_TM=`findcmd --pathOnly tm`
-  PATH_to_SHA1=`findcmd --pathOnly sha1sum`
 
   local SED
   local osType
   SED=sed
+  SHA1SUM=sha1sum
   osType=$(uname -s)
   if [ ${osType:-} = "Darwin" ]; then
     SED=gsed
+    SHA1SUM=gsha1sum
   fi
 
+  PATH_to_SHA1=`findcmd --pathOnly $SHA1SUM`
   PATH_TO_SED=`findcmd --pathOnly $SED`
 
   LUA_EXEC=$PATH_to_LUA/lua
@@ -292,6 +304,15 @@ initStdEnvVars()
   done
 }
 
+userCacheDir ()
+{
+  name='User Cache Directory *'
+  dir=$($LUA_EXEC $projectDir/src/lmod.in.lua shell --config 2>&1 | grep "$name")
+  dir=$(echo $dir | sed -e "s/$name//")
+  echo $dir
+}
+  
+
 clearTARG()
 {
   unset BUILDTARGET
