@@ -8,7 +8,7 @@ require("fileOps")
 require("serializeTbl")
 require("StandardPackage")
 
-_G.MasterControl = require("MasterControl")
+_G.MainControl   = require("MainControl")
 local ModuleA    = require("ModuleA")
 local Spider     = require("Spider")
 local concatTbl  = table.concat
@@ -29,9 +29,10 @@ describe("Testing Spider Class #Spider.",
 
                   local spider  = Spider:new()
                   local spiderT = {}
-                  _G.mcp = MasterControl.build("spider")
-                  _G.MCP = MasterControl.build("spider")
-                  spider:findAllModules({mpath}, spiderT)
+                  local mpathMapT = {}
+                  _G.mcp = MainControl.build("spider")
+                  _G.MCP = MainControl.build("spider")
+                  spider:findAllModules({mpath}, spiderT, mpathMapT)
                   local gold_spiderT = {
                      ["%ProjDir%/spec/Spider/mf/Core"]  = {
                         TACC = {
@@ -157,7 +158,7 @@ describe("Testing Spider Class #Spider.",
                   --   dbg:activateDebug(1)
                   --end
 
-                  local masterTbl  = masterTbl()
+                  local optionTbl  = optionTbl()
                   local projDir    = getenv("PROJDIR")
                   local root_mpath = pathJoin(projDir, testDir, "h/mf")
                   local mpath      = pathJoin(root_mpath,       "Core")
@@ -167,11 +168,12 @@ describe("Testing Spider Class #Spider.",
                   posix.setenv("LMOD_MAXDEPTH",   nil,        true)
                   cosmic:assign("LMOD_MAXDEPTH",  false)
 
-                  local spider = Spider:new()
-                  local spiderT = {}
-                  _G.mcp = MasterControl.build("spider")
-                  _G.MCP = MasterControl.build("spider")
-                  spider:findAllModules({mpath}, spiderT)
+                  local spider    = Spider:new()
+                  local spiderT   = {}
+                  local mpathMapT = {}
+                  _G.mcp = MainControl.build("spider")
+                  _G.MCP = MainControl.build("spider")
+                  spider:findAllModules({mpath}, spiderT, mpathMapT)
                   local gold_spiderT = {
                      ["%ProjDir%/spec/Spider/h/mf/Compiler/gcc/5.9"]  = {
                         mpich = {
@@ -182,6 +184,7 @@ describe("Testing Spider Class #Spider.",
                               ["mpich/17.200.3"]  = {
                                  ["Version"] = "17.200.3",
                                  ["canonical"] = "17.200.3",
+                                 ["changeMPATH"] = true,
                                  ["fn"] = "%ProjDir%/spec/Spider/h/mf/Compiler/gcc/5.9/mpich/17.200.3.lua",
                                  ["luaExt"] = 9,
                                  ["mpath"] = "%ProjDir%/spec/Spider/h/mf/Compiler/gcc/5.9",
@@ -225,6 +228,7 @@ describe("Testing Spider Class #Spider.",
                               ["gcc/5.9.2"]  = {
                                  ["Version"] = "5.9.2",
                                  ["canonical"] = "5.9.2",
+                                 ["changeMPATH"] = true,
                                  ["fn"] = "%ProjDir%/spec/Spider/h/mf/Core/gcc/5.9.2.lua",
                                  ["luaExt"] = 6,
                                  ["mpath"] = "%ProjDir%/spec/Spider/h/mf/Core",
@@ -303,13 +307,13 @@ describe("Testing Spider Class #Spider.",
                   }
 
                   local mpathMapT = {}
-                  sanizatizeTbl(rplmntA, masterTbl.mpathMapT, mpathMapT)
+                  sanizatizeTbl(rplmntA, optionTbl.mpathMapT, mpathMapT)
                   --print(serializeTbl{indent=true, name="mpathMapT",value = mpathMapT})
                   assert.are.same(gold_mpathMapT, mpathMapT)
 
                   local dbT = {}
                   --dbg:activateDebug(1)
-                  spider:buildDbT({mpath}, masterTbl.mpathMapT, spiderT, dbT)
+                  spider:buildDbT({mpath}, optionTbl.mpathMapT, spiderT, dbT)
                   local _dbT = {}
                   sanizatizeTbl(rplmntA, dbT, _dbT)
                   local gold_dbT = {
