@@ -46,8 +46,8 @@ require("strict")
 require("utils")
 require("myGlobals")
 
-local MasterControl   = require("MasterControl")
-MC_Access             = inheritsFrom(MasterControl)
+local MainControl     = require("MainControl")
+MC_Access             = inheritsFrom(MainControl)
 MC_Access.my_name     = "MC_Access"
 MC_Access.my_sType    = "load"
 MC_Access.my_tcl_mode = "display"
@@ -101,50 +101,51 @@ function M.whatis(self, msg)
 end
 
 
-M.always_load          = MasterControl.quiet
-M.always_unload        = MasterControl.quiet
-M.add_property         = MasterControl.quiet
-M.append_path          = MasterControl.quiet
-M.build_unload         = MasterControl.do_not_build_unload
-M.color_banner         = MasterControl.quiet
-M.complete             = MasterControl.quiet
-M.uncomplete           = MasterControl.quiet
-M.conflict             = MasterControl.quiet
-M.depends_on           = MasterControl.quiet
-M.error                = MasterControl.quiet
-M.execute              = MasterControl.execute
-M.extensions           = MasterControl.quiet
-M.family               = MasterControl.quiet
-M.inherit              = MasterControl.inherit
-M.load                 = MasterControl.quiet
-M.load_any             = MasterControl.quiet
-M.load_usr             = MasterControl.quiet
-M.message              = MasterControl.quiet
-M.msg_raw              = MasterControl.quiet
-M.mgrload              = MasterControl.quiet
-M.myFileName           = MasterControl.myFileName
-M.myModuleFullName     = MasterControl.myModuleFullName
-M.myModuleUsrName      = MasterControl.myModuleUsrName
-M.myModuleName         = MasterControl.myModuleName
-M.myModuleVersion      = MasterControl.myModuleVersion
-M.prepend_path         = MasterControl.quiet
-M.prereq               = MasterControl.quiet
-M.prereq_any           = MasterControl.quiet
-M.pushenv              = MasterControl.quiet
-M.remove_path          = MasterControl.quiet
-M.remove_property      = MasterControl.quiet
-M.report               = MasterControl.warning
-M.setenv               = MasterControl.quiet
-M.set_alias            = MasterControl.quiet
-M.set_shell_function   = MasterControl.quiet
-M.source_sh            = MasterControl.quiet
-M.try_load             = MasterControl.quiet
-M.uncomplete           = MasterControl.quiet
-M.unload               = MasterControl.quiet
-M.unload_usr           = MasterControl.quiet
-M.unsetenv             = MasterControl.quiet
-M.unset_shell_function = MasterControl.quiet
-M.usrload              = MasterControl.quiet
-M.LmodBreak            = MasterControl.quiet
+M.always_load          = MainControl.quiet
+M.always_unload        = MainControl.quiet
+M.add_property         = MainControl.quiet
+M.append_path          = MainControl.quiet
+M.build_unload         = MainControl.do_not_build_unload
+M.color_banner         = MainControl.quiet
+M.complete             = MainControl.quiet
+M.uncomplete           = MainControl.quiet
+M.conflict             = MainControl.quiet
+M.depends_on           = MainControl.quiet
+M.error                = MainControl.quiet
+M.execute              = MainControl.execute
+M.extensions           = MainControl.quiet
+M.family               = MainControl.quiet
+M.haveDynamicMPATH     = MainControl.quiet
+M.inherit              = MainControl.inherit
+M.load                 = MainControl.quiet
+M.load_any             = MainControl.quiet
+M.load_usr             = MainControl.quiet
+M.message              = MainControl.quiet
+M.msg_raw              = MainControl.quiet
+M.mgrload              = MainControl.quiet
+M.myFileName           = MainControl.myFileName
+M.myModuleFullName     = MainControl.myModuleFullName
+M.myModuleUsrName      = MainControl.myModuleUsrName
+M.myModuleName         = MainControl.myModuleName
+M.myModuleVersion      = MainControl.myModuleVersion
+M.prepend_path         = MainControl.quiet
+M.prereq               = MainControl.quiet
+M.prereq_any           = MainControl.quiet
+M.pushenv              = MainControl.setenv_env
+M.remove_path          = MainControl.quiet
+M.remove_property      = MainControl.quiet
+M.report               = MainControl.warning
+M.setenv               = MainControl.setenv_env
+M.set_alias            = MainControl.quiet
+M.set_shell_function   = MainControl.quiet
+M.source_sh            = MainControl.quiet
+M.try_load             = MainControl.quiet
+M.uncomplete           = MainControl.quiet
+M.unload               = MainControl.quiet
+M.unload_usr           = MainControl.quiet
+M.unsetenv             = MainControl.quiet
+M.unset_shell_function = MainControl.quiet
+M.usrload              = MainControl.quiet
+M.LmodBreak            = MainControl.quiet
 
 return M
