@@ -1,9 +1,12 @@
 --------------------------------------------------------------------------
--- This derived class of MasterControl just prints ever module
+-- This derived class of MainControl just prints ever module
 -- command.
 --
 -- @classmod MC_Show
 
+_G._DEBUG             = false               -- Required by the new lua posix
+local posix           = require("posix")
+
 require("strict")
 
 --------------------------------------------------------------------------
@@ -44,25 +47,26 @@ require("strict")
 
 require("utils")
 local pack          = (_VERSION == "Lua 5.1") and argsPack or table.pack -- luacheck: compat
-local MasterControl = require("MasterControl")
-MC_Show             = inheritsFrom(MasterControl)
+local MainControl   = require("MainControl")
+local setenv_posix  = posix.setenv
+MC_Show             = inheritsFrom(MainControl)
 MC_Show.my_name     = "MC_Show"
 MC_Show.my_sType    = "load"
 MC_Show.my_tcl_mode = "display"
-MC_Show.report      = MasterControl.warning
+MC_Show.report      = MainControl.warning
 
 local A             = ShowResultsA
 local M             = MC_Show
 local dbg           = require("Dbg"):dbg()
 local concatTbl     = table.concat
-M.accessMode        = MasterControl.quiet
-M.myFileName        = MasterControl.myFileName
-M.myModuleFullName  = MasterControl.myModuleFullName
-M.myModuleName      = MasterControl.myModuleName
-M.myModuleVersion   = MasterControl.myModuleVersion
-M.myModuleUsrName   = MasterControl.myModuleUsrName
-M.build_unload      = MasterControl.do_not_build_unload
-M.color_banner      = MasterControl.color_banner
+M.accessMode        = MainControl.quiet
+M.myFileName        = MainControl.myFileName
+M.myModuleFullName  = MainControl.myModuleFullName
+M.myModuleName      = MainControl.myModuleName
+M.myModuleVersion   = MainControl.myModuleVersion
+M.myModuleUsrName   = MainControl.myModuleUsrName
+M.build_unload      = MainControl.do_not_build_unload
+M.color_banner      = MainControl.color_banner
 
 
 local function l_ShowCmd(name,...)
@@ -85,21 +89,21 @@ end
 
 --------------------------------------------------------------------------
 -- Print help command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.help(self, ...)
    l_Show_help(...)
 end
 
 --------------------------------------------------------------------------
 -- Print extensions command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.extensions(self, ...)
    l_ShowCmd("extensions",...)
 end
 
 --------------------------------------------------------------------------
 -- Print whatis command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param value the whatis string.
 function M.whatis(self, value)
    l_ShowCmd("whatis", value)
@@ -107,7 +111,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print exit command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param value the whatis string.
 function show_exit(value)
    l_ShowCmd("os.exit", value)
@@ -115,7 +119,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print execute command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param t Input table describing shell command.
 function M.execute(self, t)
    local a = {}
@@ -129,7 +133,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print prepend_path command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param t input table
 function M.prepend_path(self, t)
    l_ShowCmd("prepend_path", t)
@@ -137,7 +141,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print add_property command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.add_property(self, name,value)
@@ -146,7 +150,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print set_alias command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.remove_property(self, name,value)
@@ -155,21 +159,21 @@ end
 
 --------------------------------------------------------------------------
 -- Print message command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 function M.message(self, ...)
    l_ShowCmd("LmodMessage", ...)
 end
 
 --------------------------------------------------------------------------
 -- Print message raw command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 function M.msg_raw(self, ...)
    l_ShowCmd("LmodMsgRaw", ...)
 end
 
 --------------------------------------------------------------------------
 -- Print set_alias command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.set_alias(self, name,value)
@@ -178,16 +182,17 @@ end
 
 --------------------------------------------------------------------------
 -- Print pushenv command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.pushenv(self, name,value)
+   setenv_posix(name, value, true)
    l_ShowCmd("pushenv", name, value)
 end
 
 --------------------------------------------------------------------------
 -- Print unset_alias command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param name the environment variable name.
 function M.unset_alias(self, name)
    l_ShowCmd("unset_alias",name)
@@ -195,7 +200,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print append_path command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param t input table
 function M.append_path(self, t)
    l_ShowCmd("append_path", t)
@@ -203,25 +208,27 @@ end
 
 --------------------------------------------------------------------------
 -- Print setenv command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.setenv(self, name,value)
+   setenv_posix(name, value, true)
    l_ShowCmd("setenv", name, value)
 end
 
 --------------------------------------------------------------------------
 -- Print unsetenv command.
--- @param self A MasterControl object.
+-- @param self A MainControl object.
 -- @param name the environment variable name.
 -- @param value the environment variable value.
 function M.unsetenv(self, name,value)
+   setenv_posix(name, nil, true)
    l_ShowCmd("unsetenv", name, value)
 end
 
 --------------------------------------------------------------------------
 -- Print remove_path command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param t input table
 function M.remove_path(self, t)
    l_ShowCmd("remove_path", t)
@@ -229,7 +236,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print load command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.load(self, mA)
    A[#A+1] = ShowCmdA("load",mA)
@@ -237,7 +244,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print load_any command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.load_any(self, mA)
    A[#A+1] = ShowCmdA("load_any",mA)
@@ -245,7 +252,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print mgrload command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.mgrload(self, required, active)
    A[#A+1] = l_ShowCmd("mgrload",required, active)
@@ -253,7 +260,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print depends_on command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.depends_on(self, mA)
    A[#A+1] = ShowCmdA("depends_on",mA)
@@ -263,7 +270,7 @@ M.load_usr = M.load
 
 --------------------------------------------------------------------------
 -- Print try_load command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.try_load(self, mA)
    A[#A+1] = ShowCmdA("try_load",mA)
@@ -273,21 +280,21 @@ M.try_add = M.try_load
 
 --------------------------------------------------------------------------
 -- Print inherit command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.inherit(self, ...)
    l_ShowCmd("inherit",...)
 end
 
 --------------------------------------------------------------------------
 -- Print family command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.family(self, ...)
    l_ShowCmd("family",...)
 end
 
 --------------------------------------------------------------------------
 -- Print unload command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.unload(self, mA)
    A[#A+1] = ShowCmdA("unload",mA)
@@ -295,7 +302,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print alway_load command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.always_load(self, mA)
    A[#A+1] = ShowCmdA("always_load",mA)
@@ -303,7 +310,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print always_unload command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.always_unload(self, mA)
    A[#A+1] = ShowCmdA("always_unload",mA)
@@ -311,7 +318,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print prereq command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.prereq(self, mA)
    A[#A+1] = ShowCmdA("prereq",mA)
@@ -319,7 +326,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print prereq_any command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.prereq_any(self, mA)
    A[#A+1] = ShowCmdA("prereq_any",mA)
@@ -327,15 +334,23 @@ end
 
 --------------------------------------------------------------------------
 -- Print conflict command.
--- @param self A MasterControl object
+-- @param self A MainControl object
 -- @param mA An array of module names (MName objects)
 function M.conflict(self, mA)
    A[#A+1] = ShowCmdA("conflict",mA)
 end
 
+--------------------------------------------------------------------------
+-- Print conflict command.
+-- @param self A MainControl object
+-- @param mA An array of module names (MName objects)
+function M.haveDynamicMPATH(self, mA)
+   A[#A+1] = ShowCmdA("haveDynamicMPATH",mA)
+end
+
 --------------------------------------------------------------------------
 -- Print set shell function
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.set_shell_function(self, name, bashStr, cshStr)
    local a = {}
    name    = name    or "<unknown>"
@@ -351,7 +366,7 @@ end
 
 --------------------------------------------------------------------------
 -- Print unset shell function
--- @param self A MasterControl object
+-- @param self A MainControl object
 function M.unset_shell_function(self, ...)
    l_ShowCmd("set_shell_function", ...)
 end
@@ -362,7 +377,7 @@ end
 
 function M.source_sh(self, shell, script)
    l_ShowCmd("--source_sh", shell, script)
-   MasterControl.source_sh(self, shell, script)
+   MainControl.source_sh(self, shell, script)
 end
 
 function M.complete(self, ...)
