@@ -79,7 +79,7 @@ end
 
 local function l_process(kind, value)
    if (value == nil) then return end
-   local moduleStack = masterTbl().moduleStack
+   local moduleStack = optionTbl().moduleStack
    local iStack      = #moduleStack
    local moduleT     = moduleStack[iStack].moduleT
 
@@ -104,21 +104,36 @@ function processDIR(value)
 end
 
 local function l_processNewModulePATH(path)
-   local masterTbl   = masterTbl()
-   local dirStk      = masterTbl.dirStk
+   dbg.start{"l_processNewModulePATH(path)"}
+
+   local optionTbl   = optionTbl()
+   local dirStk      = optionTbl.dirStk
    local mpath_new   = path_regularize(path)
    dirStk[#dirStk+1] = mpath_new
 
-   local mpathMapT   = masterTbl.mpathMapT
-   local moduleStack = masterTbl.moduleStack
+   local mpathMapT   = optionTbl.mpathMapT
+   local moduleStack = optionTbl.moduleStack
    local iStack      = #moduleStack
    local mpath_old   = moduleStack[iStack].mpath
+   local moduleT     = moduleStack[iStack].moduleT
    local fullName    = moduleStack[iStack].fullName
    local t           = mpathMapT[mpath_new] or {}
-   t[fullName]       = mpath_old
 
-   mpathMapT[mpath_new] = t
+   if (mpath_new ~= mpath_old) then
+      t[fullName]          = mpath_old
+      mpathMapT[mpath_new] = t
+      moduleT.changeMPATH  = true
+   end
+   dbg.printT("mpathMapT",mpathMapT)
+   dbg.fini("l_processNewModulePATH")
+end
 
+function Spider_dynamic_mpath()
+   local optionTbl   = optionTbl()
+   local moduleStack = optionTbl.moduleStack
+   local iStack      = #moduleStack
+   local moduleT     = moduleStack[iStack].moduleT
+   moduleT.changeMPATH = true
 end
 
 function Spider_append_path(kind, t)
@@ -148,49 +163,43 @@ function Spider_append_path(kind, t)
    end
 end
 
+local shellNm = "bash"
 
-local function l_findModules(mpath, mt, mList, sn, v, moduleT)
+local function l_loadMe(entryT, moduleStack, iStack, myModuleT, mt, mList, mpath, sn, msg)
+   local shell         = _G.Shell
+   local tracing       = cosmic:value("LMOD_TRACING")
+   local fn            = entryT.fn
+   local sn            = entryT.sn
+   local fullName      = entryT.fullName
+   local version       = entryT.version
+   moduleStack[iStack] = { mpath = mpath, sn = sn, fullName = fullName, moduleT = myModuleT, fn = fn}
+   local mname         = MName:new("entryT", entryT)
+   mt:add(mname, "pending")
 
-   local shell    = _G.Shell
-   local tracing  = cosmic:value("LMOD_TRACING")
-   local function l_loadMe(entryT, moduleStack, iStack, myModuleT)
-      local shellNm       = "bash"
-      local fn            = entryT.fn
-      local sn            = entryT.sn
-      local fullName      = entryT.fullName
-      local version       = entryT.version
-      moduleStack[iStack] = { mpath = mpath, sn = sn, fullName = fullName, moduleT = myModuleT, fn = fn}
-      local mname         = MName:new("entryT", entryT)
-      mt:add(mname, "pending")
-
-      if (tracing == "yes") then
-         local b          = {}
-         b[#b + 1]        = "Spider Loading: "
-         b[#b + 1]        = fullName
-         b[#b + 1]        = " (fn: "
-         b[#b + 1]        = fn or "nil"
-         b[#b + 1]        = ")\n"
-         shell:echo(concatTbl(b,""))
-      end
-
-      loadModuleFile{file=fn, help=true, shell=shellNm, reportErr=false, mList = mList}
-      hook.apply("load_spider",{fn = fn, modFullName = fullName, sn = sn})
-      mt:setStatus(sn, "active")
+   if (tracing == "yes") then
+      tracing_msg{msg, fullName, " (fn: ", fn or "nil", ")"}
    end
 
+   loadModuleFile{file=fn, help=true, shell=shellNm, reportErr=false, mList = mList}
+   hook.apply("load_spider",{fn = fn, modFullName = fullName, sn = sn})
+   mt:setStatus(sn, "active")
+   reset_env()
+end
+
+local function l_findModules(mpath, mt, mList, sn, v, moduleT)
    local entryT
-   local moduleStack = masterTbl().moduleStack
+   local moduleStack = optionTbl().moduleStack
    local iStack      = #moduleStack
    if (v.file) then
       entryT   = { fn = v.file, sn = sn, userName = sn, fullName = sn, version = false}
-      l_loadMe(entryT, moduleStack, iStack, v.metaModuleT)
+      l_loadMe(entryT, moduleStack, iStack, v.metaModuleT, mt, mList, mpath, sn, "Spider Loading:       ")
    end
    if (next(v.fileT) ~= nil) then
       for fullName, vv in pairs(v.fileT) do
          vv.Version = extractVersion(fullName, sn)
          entryT   = { fn = vv.fn, sn = sn, userName = fullName, fullName = fullName,
                       version = vv.Version }
-         l_loadMe(entryT, moduleStack, iStack, vv)
+         l_loadMe(entryT, moduleStack, iStack, vv, mt, mList, mpath, sn, "Spider Loading:       ")
       end
    end
    if (next(v.dirT) ~= nil) then
@@ -200,11 +209,35 @@ local function l_findModules(mpath, mt, mList, sn, v, moduleT)
    end
 end
 
+local function l_findChangeMPATH_modules(mpath, mt, mList, sn, v, moduleT)
+   local entryT
+   local moduleStack = optionTbl().moduleStack
+   local iStack      = #moduleStack
+   if (v.file) then
+      LmodError("Calling l_findChangeMPATH_modules w v.file")
+   end
+   if (next(v.fileT) ~= nil) then
+      for fullName, vv in pairs(v.fileT) do
+         if (vv.changeMPATH == true) then
+            vv.Version = extractVersion(fullName, sn)
+            entryT   = { fn = vv.fn, sn = sn, userName = fullName, fullName = fullName,
+                         version = vv.Version }
+            l_loadMe(entryT, moduleStack, iStack, vv, mt, mList, mpath, sn,"Spider Loading again: ")
+         end
+      end
+   end
+   if (next(v.dirT) ~= nil) then
+      for name, vv in pairs(v.dirT) do
+         l_findChangeMPATH_modules(mpath, mt, mList, sn, vv)
+      end
+   end
+end
+
 function M.searchSpiderDB(self, strA, dbT, providedByT)
    dbg.start{"Spider:searchSpiderDB({",concatTbl(strA,","),"},spider, dbT)"}
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
 
-   if (not masterTbl.regexp) then
+   if (not optionTbl.regexp) then
       for i = 1, strA.n do
          strA[i] = strA[i]:caseIndependent()
       end
@@ -259,31 +292,34 @@ function M.searchSpiderDB(self, strA, dbT, providedByT)
    return kywdT, kywdExtsT
 end
 
-
-
-
-function M.findAllModules(self, mpathA, spiderT)
+function M.findAllModules(self, mpathA, spiderT, mpathMapT)
    dbg.start{"Spider:findAllModules(",concatTbl(mpathA,", "),")"}
    spiderT.version = LMOD_CACHE_VERSION
 
    local tracing         = cosmic:value("LMOD_TRACING")
+   local dynamicCache    = (cosmic:value("LMOD_DYNAMIC_SPIDER_CACHE") ~= "no")
    local mt              = deepcopy(MT:singleton())
    local maxdepthT       = mt:maxDepthT()
-   local masterTbl       = masterTbl()
+   local optionTbl       = optionTbl()
    local moduleDirT      = {}
-   masterTbl.moduleStack = {{}}
-   masterTbl.dirStk      = {}
-   masterTbl.mpathMapT   = {}
+   optionTbl.moduleStack = {{}}
+   optionTbl.dirStk      = {}
+   optionTbl.mpathMapT   = {}
 
    local mList           = ""
    local exit            = os.exit
    os.exit               = l_nothing
    
+   local mcp_old   = mcp
+   dbg.print{"Setting mcp to ", mcp:name(),"\n"}
+   mcp = MainControl.build("spider")
+
+
    sandbox_set_os_exit(l_nothing)
    if (tracing == "no" and not dbg.active()) then
+      dbg.print{"Turning off stdio\n"}
       turn_off_stdio()
    end
-   dbg.print{"setting os.exit to l_nothing; turn off output to stderr\n"}
    if (Use_Preload) then
       local a = {}
       mList   = getenv("LOADEDMODULES") or ""
@@ -297,7 +333,7 @@ function M.findAllModules(self, mpathA, spiderT)
       mList = concatTbl(a,":")
    end
 
-   local dirStk = masterTbl.dirStk
+   local dirStk = optionTbl.dirStk
    for i = 1,#mpathA do
       local mpath = mpathA[i]
       if (isDir(mpath)) then
@@ -305,6 +341,8 @@ function M.findAllModules(self, mpathA, spiderT)
       end
    end
 
+   local seenT = {}
+
    while(#dirStk > 0) do
       repeat
 
@@ -312,31 +350,58 @@ function M.findAllModules(self, mpathA, spiderT)
          local mpath     = dirStk[#dirStk]
          dirStk[#dirStk] = nil
 
-         -- skip mpath directory if already walked.
-         if (spiderT[mpath]) then break end
-
          -- skip mpath if directory does not exist
          -- or can not be read
          local attr  = lfs.attributes(mpath)
          if (not attr or attr.mode ~= "directory" or
              (not access(mpath,"rx")))               then break end
 
-         dbg.print{"mpath: ", mpath,"\n"}
-         local moduleA     = ModuleA:__new({mpath}, maxdepthT):moduleA()
-         local T           = moduleA[1].T
-         for sn, v in pairs(T) do
-            l_findModules(mpath, mt, mList, sn, v)
+         -- skip mpath directory if already walked.
+         if (seenT[mpath] or not isDir(mpath)) then break end
+
+         if (spiderT[mpath] == nil ) then
+            dbg.print{"Running l_findModules on: ", mpath,"\n"}
+            if (tracing == "yes") then
+               tracing_msg{"Full spider search on ",mpath}
+            end
+            
+            local moduleA     = ModuleA:__new({mpath}, maxdepthT):moduleA()
+            local T           = moduleA[1].T
+            for sn, v in pairs(T) do
+               l_findModules(mpath, mt, mList, sn, v)
+            end
+            spiderT[mpath] = moduleA[1].T
+         elseif (dynamicCache) then
+            dbg.print{"Running l_findChangeMPATH_modules on: ", mpath,"\n"}
+            if (tracing == "yes") then
+               tracing_msg{"dynamic spider search on ",mpath}
+            end
+            for sn, v in pairs(spiderT[mpath]) do
+               l_findChangeMPATH_modules(mpath, mt, mList, sn, v)
+            end
          end
-         spiderT[mpath] = moduleA[1].T
+         seenT[mpath]   = true
       until true
    end
 
-   dbg.print{"Resetting os.exit back; stderr back on\n"}
+   dbg.print{"Resetting os.exit back\n"}
    os.exit               = exit
    sandbox_set_os_exit(exit)
    if (tracing == "no" and not dbg.active()) then
       turn_on_stdio()
+      dbg.print{"stderr back on\n"}
    end
+
+   local t = optionTbl.mpathMapT
+   if (next(t) ~= nil) then
+      for k,v in pairs(t) do
+         mpathMapT[k] = v
+      end
+   end
+
+   dbg.printT("mpathMapT",mpathMapT)
+   mcp = mcp_old
+   dbg.print{"Setting mcp to ", mcp:name(),"\n"}
    dbg.fini("Spider:findAllModules")
 end
 
@@ -415,15 +480,15 @@ end
 -- python after yours truly couldn't work it out.
 
 local function l_build_parentT(keepT, mpathMapT)
-   --dbg.start{"l_build_parentT(keepT, mpathMapT)"}
-   --dbg.printT("keepT",keepT)
-   --dbg.printT("mpathMapT",mpathMapT)
+   dbg.start{"l_build_parentT(keepT, mpathMapT)"}
+   dbg.printT("keepT",keepT)
+   dbg.printT("mpathMapT",mpathMapT)
 
    local function l_build_parentT_helper( mpath, fullNameA, fullNameT)
-      --dbg.start{"l_build_parentT_helper(mpath, fullNameA, fullNameT)"}
-      --dbg.print{"mpath: ",mpath,"\n"}
-      --dbg.printT("fullNameA: ",fullNameA)
-      --dbg.printT("fullNameT: ",fullNameT)
+      dbg.start{"l_build_parentT_helper(mpath, fullNameA, fullNameT)"}
+      dbg.print{"mpath: ",mpath,"\n"}
+      dbg.printT("fullNameA: ",fullNameA)
+      dbg.printT("fullNameT: ",fullNameT)
 
       local resultA
       if (not mpathMapT[mpath]) then
@@ -442,8 +507,8 @@ local function l_build_parentT(keepT, mpathMapT)
             end
          end
       end
-      --dbg.printT("resultA",resultA)
-      --dbg.fini("l_build_parentT_helper")
+      dbg.printT("resultA",resultA)
+      dbg.fini("l_build_parentT_helper")
       return resultA
    end
 
@@ -463,13 +528,15 @@ local function l_build_parentT(keepT, mpathMapT)
       end
    end
 
-   --dbg.printT("parentT",parentT)
-   --dbg.fini("l_build_parentT")
+   dbg.printT("parentT",parentT)
+   dbg.fini("l_build_parentT")
    return parentT
 end
 
 local function l_build_mpathParentT(mpathMapT)
+   dbg.start{"l_build_mpathParentT(mpathMapT)"}
    local mpathParentT = {}
+   dbg.printT("mpathMapT",mpathMapT)
    for mpath, vv in pairs(mpathMapT) do
       local a = mpathParentT[mpath] or {}
       for k, v in pairs(vv) do
@@ -486,6 +553,7 @@ local function l_build_mpathParentT(mpathMapT)
       end
       mpathParentT[mpath]  = a
    end
+   dbg.fini("l_build_mpathParentT")
    return mpathParentT
 end
 
@@ -534,7 +602,11 @@ local dbT_keyA = { 'Description', 'Category', 'URL', 'Version', 'whatis', 'dirA'
 
 function M.buildDbT(self, mpathA, mpathMapT, spiderT, dbT)
    dbg.start{"Spider:buildDbT(mpathMapT,spiderT, dbT)"}
+   dbg.printT("mpathMapT",mpathMapT)
    local mpathParentT = l_build_mpathParentT(mpathMapT)
+   dbg.printT("spiderT",spiderT)
+   dbg.printT("mpathParentT",mpathParentT)
+   dbg.printT("mpathA",mpathA)
    local keepT        = l_build_keepT(mpathA, mpathParentT, spiderT)
    local parentT      = l_build_parentT(keepT, mpathMapT)
    local mrc          = MRC:singleton()
@@ -616,7 +688,7 @@ end
 function M.buildProvideByT(self, dbT, providedByT)
    dbg.start{"Spider:buildProvideByT(dbT, providedByT)"}
 
-   local show_hidden = masterTbl().show_hidden
+   local show_hidden = optionTbl().show_hidden
    local mrc = MRC:singleton()
    for sn, vv in pairs(dbT) do
       for fullPath, v in pairs(vv) do
@@ -664,16 +736,14 @@ function M.buildProvideByT(self, dbT, providedByT)
 
    dbg.printT("providedByT",providedByT)
    dbg.fini("Spider:buildProvideByT")
-
-
 end
 
 
 function M.Level0_terse(self,dbT, providedByT)
    dbg.start{"Spider:Level0_terse()"}
    local mrc         = MRC:singleton()
-   local masterTbl   = masterTbl()
-   local show_hidden = masterTbl.show_hidden
+   local optionTbl   = optionTbl()
+   local show_hidden = optionTbl.show_hidden
    local t           = {}
    local a           = {}
    for sn, vv in pairs(dbT) do
@@ -702,6 +772,7 @@ function M.Level0_terse(self,dbT, providedByT)
    for k,v in pairsByKeys(t) do
       a[#a+1] = v
    end
+   a[#a+1] = ""
    dbg.fini("Spider:Level0_terse")
    return concatTbl(a,"\n")
 end
@@ -709,7 +780,7 @@ end
 function M.Level0(self, dbT, providedByT)
    local a = {}
 
-   if (masterTbl().terse) then
+   if (optionTbl().terse) then
       return self:Level0_terse(dbT, providedByT)
    end
 
@@ -745,8 +816,8 @@ end
 
 function M.Level0Helper(self, dbT, providedByT, a)
    local t           = {}
-   local masterTbl   = masterTbl()
-   local show_hidden = masterTbl.show_hidden
+   local optionTbl   = optionTbl()
+   local show_hidden = optionTbl.show_hidden
    local term_width  = TermWidth() - 4
    local banner      = Banner:singleton()
    local mrc         = MRC:singleton()
@@ -832,8 +903,8 @@ end
 
 function M.spiderSearch(self, dbT, providedByT, userSearchPat, helpFlg)
    dbg.start{"Spider:spiderSearch(dbT,providedByT,\"",userSearchPat,"\",",helpFlg,")"}
-   local masterTbl   = masterTbl()
-   local show_hidden = masterTbl.show_hidden
+   local optionTbl   = optionTbl()
+   local show_hidden = optionTbl.show_hidden
    local mrc         = MRC:singleton()
 
    dbg.print{"show_hidden: ",show_hidden,"\n"}
@@ -841,7 +912,7 @@ function M.spiderSearch(self, dbT, providedByT, userSearchPat, helpFlg)
    --dbg.printT("dbT",dbT)
 
    local origUserSearchPat = userSearchPat
-   if (not masterTbl.regexp) then
+   if (not optionTbl.regexp) then
       userSearchPat = userSearchPat:caseIndependent()
    end
 
@@ -991,8 +1062,8 @@ end
 
 function M._Level1(self, dbT, providedByT, possibleA, sn, key, helpFlg)
    dbg.start{"Spider:_Level1(dbT, providedByT, possibleA, sn: \"",sn,"\", key: \"",key,"\")"}
-   local masterTbl   = masterTbl()
-   local show_hidden = masterTbl.show_hidden
+   local optionTbl   = optionTbl()
+   local show_hidden = optionTbl.show_hidden
    local term_width  = TermWidth() - 4
    local mrc         = MRC:singleton()
    local T           = dbT[sn]
@@ -1190,7 +1261,7 @@ function M._Level1(self, dbT, providedByT, possibleA, sn, key, helpFlg)
 
    local a  = {}
    local ia = 0
-   if (masterTbl.terse) then
+   if (optionTbl.terse) then
       for k, v in pairsByKeys(fullVT) do
          if (not v.providedBy) then
             ia = ia + 1; a[ia] = v.fullName .. "\n"
@@ -1251,7 +1322,7 @@ function M._Level2(self, sn, fullName, entryA, entryPA, possibleA, tailMsg)
    dbg.start{"Spider:_Level2(\"",sn,"\", \"",fullName,"\", entryA, entryPA, possibleA, tailMsg)"}
    --dbg.printT("entryA",entryA)
 
-   local show_hidden  = masterTbl().show_hidden
+   local show_hidden  = optionTbl().show_hidden
    local a            = {}
    local ia           = 0
    local b            = {}
