@@ -51,7 +51,7 @@ local BeautifulTbl = require('BeautifulTbl')
 local Cache        = require("Cache")
 local ColumnTable  = require('ColumnTable')
 local FrameStk     = require('FrameStk')
-local Master       = require('Master')
+local Hub          = require('Hub')
 local MName        = require("MName")
 local Spider       = require("Spider")
 local Version      = require("Version")
@@ -65,6 +65,7 @@ local lfs          = require("lfs")
 local sort         = table.sort
 local pack         = (_VERSION == "Lua 5.1") and argsPack or table.pack  -- luacheck: compat
 local unpack       = (_VERSION == "Lua 5.1") and unpack or table.unpack  -- luacheck: compat
+local s_purgeFlg   = false
 
 local system_name  = cosmic:value("LMOD_SYSTEM_NAME")
 
@@ -75,129 +76,212 @@ local system_name  = cosmic:value("LMOD_SYSTEM_NAME")
 -- depending on what mode Access is called with.
 -- @param mode Whether this function has be called via *Help* or *Whatis*.
 local function l_Access(mode, ...)
-   local master    = Master:singleton()
+   local hub    = Hub:singleton()
    local shell     = _G.Shell
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
    dbg.start{"l_Access(", concatTbl({...},", "),")"}
-   mcp = MasterControl.build("access", mode)
+   mcp = MainControl.build("access", mode)
    mcp:setAccessMode(mode,true)
 
    local n = select('#',...)
    if (n < 1) then
-      shell:echo(masterTbl.cmdHelpMsg, "\n", Usage(), "\n", version())
+      shell:echo(optionTbl.cmdHelpMsg, "\n", Usage(), "\n", version())
       dbg.fini("l_Access")
       return
    end
 
-   master:access(...)
+   hub:access(...)
    mcp:setAccessMode(mode,false)
    dbg.fini("l_Access")
 end
 
 --------------------------------------------------------------------------
--- This helper function walks the ~/.lmod.d directory and reports back
+-- This helper function walks the Collection directories and reports back
 -- the list of named collections. Note that names that start with "."
 -- or end with "~" or start with "__" are ignored.
 -- @param a An array containing the results.
 -- @param path The Lmod.d directory path.
-local function findNamedCollections(a,path)
-   if (not isDir(path)) then return end
-   for file in lfs.dir(path) do
-      if (file:sub(1,1) ~= "." and file:sub(-1) ~= "~" and
-          file:sub(1,2) ~= "__") then
-         local f    = pathJoin(path,file)
-         local attr = lfs.attributes(f)
-         if (attr and attr.mode == "directory") then
-            findNamedCollections(a,f)
-         else
-            local idx    = file:find("%.")
-            local accept = (not idx) and (not system_name)
-            if (idx and system_name) then
-               accept    = file:sub(idx+1,-1) == system_name
-               f         = pathJoin(path, file:sub(1,idx-1))
-            end
-            if (accept) then
-               a[#a+1] = f
+local function l_findNamedCollections(a,pathA)
+   local t = {}
+   for i = 1,#pathA do
+      repeat 
+         local path = pathA[i]
+         if (not isDir(path)) then break end
+         for file in lfs.dir(path) do
+            if (file:sub(1,1) ~= "." and file:sub(-1) ~= "~" and
+                file:sub(1,2) ~= "__") then
+               local f    = pathJoin(path,file)
+               local attr = lfs.attributes(f)
+               if (attr and attr.mode == "directory") then
+                  l_findNamedCollections(a,{f})
+               else
+                  local idx    = file:find("%.")
+                  local accept = (not idx) and (not system_name)
+                  if (idx and system_name) then
+                     accept    = file:sub(idx+1,-1) == system_name
+                     f         = pathJoin(path, file:sub(1,idx-1))
+                  end
+                  if (accept) then
+                     t[file] = attr.modification
+                  end
+               end
             end
          end
+      until (true)
+   end
+   if (next(t) ~= nil) then
+      for k in pairsByKeys(t) do
+         a[#a+1] = k
+      end
+      table.sort(a)
+   end
+end
+
+------------------------------------------------------------------------
+-- Just convert the vararg into an actual array and call
+-- hub.avail to do the real work.
+function Avail(...)
+   local shell = _G.Shell
+   local a     = hub:avail(pack(...))
+   if (next(a) ~= nil) then
+      shell:echo(concatTbl(a,""))
+   end
+end
+
+------------------------------------------------------------------------
+function Category(...)
+   dbg.start{"Category(", concatTbl({...},", "),")"}
+   local shell = _G.Shell
+
+
+   local cache = Cache:singleton{buildCache = true}
+   local moduleT, dbT = cache:build()
+
+   local categoryT = {}
+
+   local function add_module(cat, name)
+      if (cat == "") then return
+      elseif (categoryT[cat] == nil) then
+         dbg.print{"found new category: ", cat, "\n"}
+         categoryT[cat] = {}
+      end
+
+      if (not categoryT[cat][name]) then
+         dbg.print{"found new sn: ", name, " in category: ", cat, "\n"}
+         categoryT[cat][name] = 1
+      else
+         categoryT[cat][name] = categoryT[cat][name] + 1
+      end
+   end
+
+   for sn, v in pairs(dbT) do
+      for _, info in pairs(v) do
+         local category = info.Category or ""
+
+         for entry in category:split(",") do
+            entry = entry:trim()
+            add_module(entry, sn)
+         end
       end
    end
-   table.sort(a)
-end
 
-------------------------------------------------------------------------
--- Just convert the vararg into an actual array and call
--- master.avail to do the real work.
-function Avail(...)
-   local shell = _G.Shell
-   local a     = master:avail(pack(...))
-   if (next(a) ~= nil) then
-      shell:echo(concatTbl(a,""))
+   local masterTbl = masterTbl()
+   local search = ... and true
+   local twidth = TermWidth()
+   local cwidth = masterTbl.rt and LMOD_COLUMN_TABLE_WIDTH or twidth
+   local banner = Banner:singleton()
+
+   local a = {}
+
+   if (not search) then
+      dbg.print{"printing category block\n"}
+      a[#a+1] = "\n"
+      a[#a+1] = [[
+To get a list of every module in a category execute:
+   $ module category Foo
+      ]]
+      a[#a+1] = "\n"
+      a[#a+1] = banner:bannerStr("List of Categories")
+      a[#a+1] = "\n"
+
+      local b = {}
+      for cat, _ in pairsByKeys(categoryT) do
+         b[#b+1] = cat 
+      end
+
+      b = hook.apply("category", "simple", b) or b
+
+      local ct = ColumnTable:new{tbl=b, gap=2, len=length, width = cwidth-5}
+      a[#a+1] = ct:build_tbl()
+      a[#a+1] = "\n"
+   else
+      local argA = pack(...)
+      local searchA = {}
+
+      for i = 1, argA.n do
+         searchA[i] = argA[i]:caseIndependent()
+      end
+      searchA.n = argA.n
+
+      local match = hook.apply("category", "complex", categoryT) or {}
+
+      if (next(match) == nil) then
+         for cat, v in pairsByKeys(categoryT) do
+            for i = 1, searchA.n do
+               if (cat:find(searchA[i])) then
+                  match[cat] = v
+               end
+            end
+         end
+      end
+
+      a[#a+1] = "\n"
+      a[#a+1] = [[
+To learn more about a package and how to load it execute:
+   $ module spider Bar
+      ]]
+
+      if (next(match) == nil) then
+         a[#a+1] = "\n"
+         a[#a+1] = "No matching category found."
+         a[#a+1] = "\n"
+      end
+
+      for cat, v in pairsByKeys(match) do
+         local b = {}
+
+         for sn, count in pairsByKeys(v) do
+            b[#b+1] = { sn, "(" .. tostring(count) .. ")  " }
+         end
+
+         dbg.print{"printing category block\n"}
+         local ct = ColumnTable:new{tbl = b, gap = 1, len = length, width = cwidth}
+         a[#a+1] = "\n"
+         a[#a+1] = banner:bannerStr(cat)
+         a[#a+1] = "\n"
+         a[#a+1] = ct:build_tbl()
+         a[#a+1] = "\n"
+      end
    end
+
+   if (next(a) ~= nil) then
+      shell:echo(concatTbl(a, ""))
+   end
+   dbg.fini("Category")
 end
 
 ------------------------------------------------------------------------
 -- Just convert the vararg into an actual array and call
--- master.overview to do the real work.
+-- hub.overview to do the real work.
 
 function Overview(...)
    local shell = _G.Shell
-   local a     = master:overview(pack(...))
+   local a     = hub:overview(pack(...))
    if (next(a) ~= nil) then
       shell:echo(concatTbl(a,""))
    end
 end
 
---------------------------------------------------------------------------
--- Report the modules in the requested collection
-function CollectionLst(collection)
-   collection  = collection or "default"
-   dbg.start{"CollectionLst(",collection,")"}
-   local masterTbl = masterTbl()
-   local sname     = (not system_name) and "" or "." .. system_name
-   local path      = pathJoin(os.getenv("HOME"), ".lmod.d", collection .. sname)
-   local mt        = FrameStk:singleton():mt()
-   local a         = mt:reportContents{fn=path, name=collection}
-   local shell     = _G.Shell
-   local cwidth    = masterTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
-   if (masterTbl.terse) then
-      for i = 1,#a do
-         shell:echo(a[i].."\n")
-      end
-   else
-      if (#a < 1) then
-         LmodWarning{msg="w_No_Coll",collection=collection}
-         dbg.fini("CollectionLst")
-         return
-      end
-      shell:echo(i18n("coll_contains",{collection=collection}))
-      local b = {}
-      for i = 1,#a do
-         b[#b+1] = { "   " .. tostring(i) .. ")", a[i] }
-      end
-      local ct = ColumnTable:new{tbl=b, gap = 0, width = cwidth}
-      shell:echo(ct:build_tbl(),"\n")
-   end
-   dbg.fini("CollectionLst")
-end
-
-
---------------------------------------------------------------------------
--- Get the command line argument and use MT:getMTfromFile()
--- to read the module table from the file and use that
--- collections of module to load.  This routine is deprecated
--- and will be removed.  Use restore instead.
--- @param collection The collection name (default="default")
-function GetDefault(collection)
-   collection  = collection or "default"
-   dbg.start{"GetDefault(",collection,")"}
-
-   local sname = (not system_name) and "" or "." .. system_name
-   local path  = pathJoin(os.getenv("HOME"), ".lmod.d", collection .. sname)
-   local mt    = FrameStk:singleton():mt()
-   mt:getMTfromFile{fn=path, name=collection, }
-   dbg.fini("GetDefault")
-end
 
 --------------------------------------------------------------------------
 -- Define the prtHdr function and use the helper function Access()
@@ -256,8 +340,8 @@ function Keyword(...)
    local spider                 = Spider:new()
    local a                      = {}
    local ia                     = 0
-   local masterTbl              = masterTbl()
-   local terse                  = masterTbl.terse
+   local optionTbl              = optionTbl()
+   local terse                  = optionTbl.terse
    local kywdT,kywdExtsT        = spider:searchSpiderDB(pack(...), dbT, providedByT)
 
    if (terse) then
@@ -281,14 +365,17 @@ end
 -- List the loaded modulefile
 function List(...)
    dbg.start{"List(...)"}
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
    local shell     = _G.Shell
    local frameStk  = FrameStk:singleton()
    local mt        = frameStk:mt()
-   local activeA   = mt:list("fullName","active")
-   local inactiveA = mt:list("fullName","inactive")
+
+   local kind      = optionTbl.brief and "fullName_Meta" or "fullName"
+
+   local activeA   = mt:list(kind,"active")
+   local inactiveA = mt:list(kind,"inactive")
    local total     = #activeA + #inactiveA
-   local cwidth    = masterTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
+   local cwidth    = optionTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
 
    dbg.print{"#activeA:   ",#activeA,"\n"}
    dbg.print{"#inactiveA: ",#inactiveA,"\n"}
@@ -313,14 +400,14 @@ function List(...)
       wanted.n  = 1
    else
       msg2 = i18n("matching",{wanted = table.concat(wanted," or ")})
-      if (not masterTbl.regexp) then
+      if (not optionTbl.regexp) then
          for i = 1, wanted.n do
             wanted[i] = wanted[i]:caseIndependent()
          end
       end
    end
 
-   if (masterTbl.terse) then
+   if (optionTbl.terse) then
       for i = 1,#activeA do
          local fullName = activeA[i].fullName
          for j = 1, wanted.n do
@@ -499,6 +586,9 @@ function Purge_Usr()
 end
 
 
+function purgeFlg()
+   return s_purgeFlg
+end
 --------------------------------------------------------------------------
 -- Unload all loaded modules.
 -- @param force If true then sticky modules are unloaded as well.
@@ -516,7 +606,9 @@ function Purge(force)
       mA[#mA+1] = MName:new("mt",totalA[i])
    end
    dbg.start{"Purge(",concatTbl(totalA,", "),")"}
+   s_purgeFlg = true
    unload_usr_internal(mA, force)
+   s_purgeFlg = false
 
    -- A purge should not set the warning flag.
    clearWarningFlag()
@@ -531,8 +623,8 @@ end
 -- defined.
 function Refresh()
    dbg.start{"Refresh()"}
-   local master  = Master:singleton()
-   master:refresh()
+   local hub  = Hub:singleton()
+   hub:refresh()
    dbg.fini("Refresh")
 end
 
@@ -544,7 +636,7 @@ end
 -- @param msg If true then print resetting message.
 function Reset(msg)
    dbg.start{"Reset()"}
-   local default = os.getenv("LMOD_SYSTEM_DEFAULT_MODULES") or ""
+   local default = cosmic:value("LMOD_SYSTEM_DEFAULT_MODULES")
    if (default == "") then
       if (not quiet()) then
          io.stderr:write(i18n("w_SYS_DFLT_EMPTY",{}))
@@ -609,17 +701,113 @@ function Reset(msg)
    end
 
 
-   local a = {}
-   for m in default:split(":") do
-      dbg.print{"m: ",m,"\n"}
-      a[#a + 1] = m
+   if (default ~= "__NO_SYSTEM_DEFAULT_MODULES__") then
+      local a = {}
+      for m in default:split(":") do
+         dbg.print{"m: ",m,"\n"}
+         a[#a + 1] = m
+      end
+      if (#a > 0) then
+         Load_Usr(unpack(a))
+      end
+      dbg.fini("Reset")
    end
-   if (#a > 0) then
-      Load_Usr(unpack(a))
-   end
-   dbg.fini("Reset")
 end
 
+local function l_collectionDir(mode)
+   local a        = {}
+   local home     = os.getenv("HOME") or ""
+   local dotConfD = pathJoin(home,".config/lmod")
+   local dotLmodD = pathJoin(home,".lmod.d")
+   if (mode == "write") then
+      local configDirOnly = cosmic:value("LMOD_USE_DOT_CONFIG_ONLY")
+      if (configDirOnly == "no") then
+         a[#a+1] = dotLmodD
+      end
+      a[#a+1] = dotConfD
+   else
+      a[#a+1] = dotConfD
+      a[#a+1] = dotLmodD
+   end
+   return a 
+end
+      
+            
+
+local function l_find_a_collection(collectionName)
+   local pathA = l_collectionDir("read")
+   local result = nil
+   local timeStamp = 0
+   for i = 1,#pathA do
+      local path = pathJoin(pathA[i], collectionName)
+      if (isFile(path)) then
+         local attr = lfs.attributes(path)
+         if (attr and type(attr) == "table" and attr.modification > timeStamp) then
+            timeStamp = attr.modification
+            result    = path
+         end
+      end
+   end
+   return result
+end
+
+--------------------------------------------------------------------------
+-- Report the modules in the requested collection
+function CollectionLst(collection)
+   collection  = collection or "default"
+   dbg.start{"CollectionLst(",collection,")"}
+   local optionTbl = optionTbl()
+   local sname     = (not system_name) and "" or "." .. system_name
+   local mt        = FrameStk:singleton():mt()
+   local shell     = _G.Shell
+   local cwidth    = optionTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
+   local path      = l_find_a_collection(collection)
+
+   local a         = mt:reportContents{fn=path, name=collection}
+   if (optionTbl.terse) then
+      for i = 1,#a do
+         shell:echo(a[i].."\n")
+      end
+   else
+      if (#a < 1) then
+         LmodWarning{msg="w_No_Coll",collection=collection}
+         dbg.fini("CollectionLst")
+         return
+      end
+      shell:echo(i18n("coll_contains",{collection=collection}))
+      local b = {}
+      for i = 1,#a do
+         b[#b+1] = { "   " .. tostring(i) .. ")", a[i] }
+      end
+      local ct = ColumnTable:new{tbl=b, gap = 0, width = cwidth}
+      shell:echo(ct:build_tbl(),"\n")
+   end
+   dbg.fini("CollectionLst")
+end
+
+
+--------------------------------------------------------------------------
+-- Get the command line argument and use MT:getMTfromFile()
+-- to read the module table from the file and use that
+-- collections of module to load.  This routine is deprecated
+-- and will be removed.  Use restore instead.
+-- @param collection The collection name (default="default")
+function GetDefault(collection)
+   collection  = collection or "default"
+   dbg.start{"GetDefault(",collection,")"}
+
+   local sname = (not system_name) and "" or "." .. system_name
+   local path  = l_find_a_collection(collection .. sname)
+   if (not path) then
+      LmodError{msg="e_Unknown_Coll", collection = collection}
+   end
+
+   local mt    = FrameStk:singleton():mt()
+   mt:getMTfromFile{fn=path, name=collection}
+   dbg.fini("GetDefault")
+end
+
+
 --------------------------------------------------------------------------
 -- Restore the state of the user's loaded modules original
 -- state. If a user has a "default" then use that collection.
@@ -642,8 +830,8 @@ function Restore(collection)
    end
 
    if (collection == nil) then
-      path = pathJoin(os.getenv("HOME"), ".lmod.d", "default" .. sname)
-      if (not isFile(path)) then
+      path = l_find_a_collection("default" .. sname)
+      if (not path) then
          collection = "system"
          myName = collection
       else
@@ -651,8 +839,8 @@ function Restore(collection)
       end
    elseif (collection ~= "system") then
       myName = collection
-      path   = pathJoin(os.getenv("HOME"), ".lmod.d", collection .. sname)
-      if (not isFile(path)) then
+      path   = l_find_a_collection(collection .. sname)
+      if (not path) then
          LmodError{msg="e_Unknown_Coll", collection = collection}
       end
    end
@@ -662,7 +850,7 @@ function Restore(collection)
    end
 
 
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
 
    if (collection == "system" ) then
       msg = "system default" .. msgTail
@@ -671,7 +859,7 @@ function Restore(collection)
       msg        = "user's ".. collection .. msgTail
    end
 
-   if (masterTbl.quiet or masterTbl.initial) then
+   if (optionTbl.quiet or optionTbl.initial) then
       msg = false
    end
 
@@ -704,11 +892,12 @@ end
 -- complicated but a "manager" module file is "fake" loaded so
 -- that any setenv or prepend_path commands will not be executed.
 function Save(...)
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
    local frameStk  = FrameStk:singleton()
    local mt        = frameStk:mt()
    local a         = select(1, ...) or "default"
-   local path      = pathJoin(os.getenv("HOME"), LMODdir)
+   local home      = os.getenv("HOME")
+   local pathA     = l_collectionDir("write")
    dbg.start{"Save(",concatTbl({...},", "),")"}
 
    local msgTail = ""
@@ -733,33 +922,37 @@ function Save(...)
    end
 
    local activeA = mt:list("short","active")
-   local force   = masterTbl.force
+   local force   = optionTbl.force
    if (#activeA == 0 and not force) then
       LmodWarning{msg="w_Save_Empty_Coll",name=a}
       dbg.fini("Save")
       return
    end
 
-   local attr = lfs.attributes(path)
-   if (not attr) then
-      mkdir_recursive(path)
-   end
-   path = pathJoin(path, a .. sname)
-   if (isFile(path)) then
-      os.rename(path, path .. "~")
-   end
    mt:setHashSum()
    local varT = frameStk:varT()
    mt:setMpathRefCountT(varT[ModulePath]:refCountT())
 
-   local f  = io.open(path,"w")
-   if (f) then
-      f:write("-- -*- lua -*-\n")
-      f:write("-- created: ",os.date()," --\n")
-      local s0 = "-- Lmod ".. Version.name() .. "\n"
-      local s1 = mt:serializeTbl("pretty")
-      f:write(s0,s1)
-      f:close()
+   local date = os.date()
+   for i = 1,#pathA do
+      local path = pathA[i]
+      local attr = lfs.attributes(path)
+      if (not attr) then
+         mkdir_recursive(path)
+      end
+      local fn = pathJoin(path, a .. sname)
+      if (isFile(fn)) then
+         os.rename(fn, fn .. "~")
+      end
+      local f  = io.open(fn,"w")
+      if (f) then
+         f:write("-- -*- lua -*-\n")
+         f:write("-- created: ",date," --\n")
+         local s0 = "-- Lmod ".. Version.name() .. "\n"
+         local s1 = mt:serializeTbl("pretty")
+         f:write(s0,s1)
+         f:close()
+      end
    end
    mt:hideMpathRefCountT()
    mt:hideHash()
@@ -774,21 +967,18 @@ end
 -- Report to the user all the named collections he/she has.
 function SaveList(...)
    local mt        = FrameStk:singleton():mt()
-   local path      = pathJoin(os.getenv("HOME"), LMODdir)
-   local masterTbl = masterTbl()
+   local optionTbl = optionTbl()
    local a         = {}
    local b         = {}
    local shell     = _G.Shell
-   local cwidth    = masterTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
+   local cwidth    = optionTbl.rt and LMOD_COLUMN_TABLE_WIDTH or TermWidth()
+   local home      = os.getenv("HOME")
+   local pathA     = l_collectionDir("read")
 
-   findNamedCollections(b,path)
-   if (masterTbl.terse) then
+   l_findNamedCollections(b,pathA)
+   if (optionTbl.terse) then
       for k = 1,#b do
          local name = b[k]
-         local i,j  = name:find(path,1,true)
-         if (i) then
-            name = name:sub(j+2)
-         end
          shell:echo(name.."\n")
       end
       return
@@ -797,10 +987,6 @@ function SaveList(...)
 
    for k = 1,#b do
       local name = b[k]
-      local i,j  = name:find(path,1,true)
-      if (i) then
-         name = name:sub(j+2)
-      end
       local cstr = string.format("%3d) ",k)
       a[#a+1] = cstr .. name
    end
@@ -829,15 +1015,15 @@ function SearchCmd(...)
 end
 
 --------------------------------------------------------------------------
--- Use the show mode of MasterControl to list the active Lmod
+-- Use the show mode of MainControl to list the active Lmod
 -- commands in a module file.  Note that the output is always in Lua
 -- even if the modulefile is written in TCL.
 function Show(...)
-   local master = Master:singleton()
+   local hub = Hub:singleton()
    local banner = Banner:singleton()
    dbg.start{"Show(", concatTbl({...},", "),")"}
 
-   mcp = MasterControl.build("show")
+   mcp = MainControl.build("show")
    local borderStr = banner:border(0)
 
    _G.prtHdr     = function()
@@ -851,7 +1037,7 @@ function Show(...)
                   end
    local exit = os.exit
    sandbox_set_os_exit(show_exit)
-   master:access(...)
+   hub:access(...)
    os.exit = exit
    dbg.fini("Show")
 end
@@ -864,7 +1050,7 @@ function SpiderCmd(...)
    dbg.start{"SpiderCmd(", concatTbl({...},", "),")"}
    local cache                  = Cache:singleton{buildCache=true}
    local shell                  = _G.Shell
-   local masterTbl              = masterTbl()
+   local optionTbl              = optionTbl()
    local spiderT,dbT,
          mpathMapT, providedByT = cache:build()
    local spider                 = Spider:new()
@@ -882,7 +1068,7 @@ function SpiderCmd(...)
       end
       s = concatTbl(a,"")
    end
-   if (masterTbl.terse) then
+   if (optionTbl.terse) then
       shell:echo(s.."\n")
    else
       local a = {}
@@ -936,7 +1122,7 @@ function Swap(...)
 
    mname       = mA[1]
    sn          = mname:sn()
-   local usrN  = (not masterTbl().latest) and b or mt:fullName(sn)
+   local usrN  = (not optionTbl().latest) and b or mt:fullName(sn)
    mt:userLoad(sn,usrN)
    dbg.fini("Swap")
 end
@@ -965,7 +1151,7 @@ end
 -- Disable a collection
 function Disable(...)
    local shell = _G.Shell
-   local path  = pathJoin(os.getenv("HOME"), LMODdir)
+   local pathA = l_collectionDir("read")
    local argA  = pack(...)
    local sname = (not system_name) and "" or "." .. system_name
 
@@ -976,10 +1162,13 @@ function Disable(...)
 
    for i = 1,argA.n do
       local name  = argA[i]
-      local fn    = pathJoin(path,name .. sname)
-      local fnNew = fn .. "~"
-      os.rename(fn, fnNew)
       shell:echo(i18n("m_Collection_disable",{name=name}))
+      for j = 1,#pathA do
+         local path  = pathA[j]
+         local fn    = pathJoin(path,name .. sname)
+         local fnNew = fn .. "~"
+         os.rename(fn, fnNew)
+      end
    end
 end
 
@@ -987,9 +1176,9 @@ end
 --------------------------------------------------------------------------
 --  Reload all modules.
 function Update()
-   local master = Master:singleton()
+   local hub = Hub:singleton()
    local force_update = true
-   master:reloadAll(force_update)
+   hub:reloadAll(force_update)
 end
 
 --------------------------------------------------------------------------
@@ -1036,10 +1225,10 @@ function Use(...)
       op(mcp, { ModulePath,  v, delim = ":", nodups=true, priority=priority })
    end
 
-   local master    = Master:singleton()
+   local hub    = Hub:singleton()
    if (mt:changeMPATH()) then
       mt:reset_MPATH_change_flag()
-      master.reloadAll()
+      hub.reloadAll()
    end
    mcp = mcp_old
    dbg.fini("Use")
@@ -1060,7 +1249,7 @@ function UnUse(...)
    end
    if (mt:changeMPATH()) then
       mt:reset_MPATH_change_flag()
-      master.reloadAll()
+      hub.reloadAll()
    end
    dbg.fini("UnUse")
 end
@@ -1071,6 +1260,7 @@ function UnLoad(...)
    dbg.start{"UnLoad(",concatTbl({...},", "),")"}
    local force = false
    unload_usr_internal(MName:buildA("mt", ...), force)
+   mcp:mustLoad()
    dbg.fini("UnLoad")
 end
 
