@@ -113,7 +113,7 @@ require("string_utils")
 require("cmdfuncs")
 require("utils")
 
-MasterControl       = require("MasterControl")
+MainControl         = require("MainControl")
 
 local Banner        = require("Banner")
 local BaseShell     = require("BaseShell")
@@ -140,8 +140,8 @@ function Usage()
    if (s_Usage) then
       return s_Usage
    end
-   local website = colorize("red","http://lmod.readthedocs.org/")
-   local webBR   = colorize("red","http://lmod.readthedocs.io/en/latest/075_bug_reporting.html")
+   local website = colorize("red","https://lmod.readthedocs.org/")
+   local webBR   = colorize("red","https://lmod.readthedocs.io/en/latest/075_bug_reporting.html")
    local banner  = Banner:singleton()
    local line    = banner:border(2)
    local a = {}
@@ -165,6 +165,8 @@ function Usage()
    a[#a+1] = { "  list",          "s1 s2 ...",    i18n("list2")  }
    a[#a+1] = { "  avail | av",    "",             i18n("list3")  }
    a[#a+1] = { "  avail | av",    "string",       i18n("list4")  }
+   a[#a+1] = { "  category | cat","",             "List all categories" }
+   a[#a+1] = { "  category | cat","s1 s2 ...",    "List all categories that match the pattern and display their modules" }
    a[#a+1] = { "  overview | ov", "",             i18n("ov1")    }
    a[#a+1] = { "  overview | ov", "string",       i18n("ov2")    }
    a[#a+1] = { "  spider",        "",             i18n("list5")  }
@@ -213,7 +215,7 @@ function Usage()
    a[#a+1] = { line}
    a[#a+1] = { i18n("web_sites") }
    a[#a+1] = { "" }
-   a[#a+1] = { "  Documentation:    http://lmod.readthedocs.org"}
+   a[#a+1] = { "  Documentation:    https://lmod.readthedocs.org"}
    a[#a+1] = { "  GitHub:           https://github.com/TACC/Lmod"}
    a[#a+1] = { "  SourceForge:      https://lmod.sf.net"}
    a[#a+1] = { "  TACC Homepage:    https://www.tacc.utexas.edu/research-development/tacc-projects/lmod"}
@@ -276,10 +278,12 @@ function main()
    local whatisTbl    = { name = "whatis",      checkMPATH = false, cmd = Whatis        }
    local isLoadedTbl  = { name = "isLoaded",    checkMPATH = false, cmd = IsLoaded      }
    local isAvailTbl   = { name = "isAvail",     checkMPATH = false, cmd = IsAvail       }
+   local categoryTbl  = { name = "category",    checkMPATH = true,  cmd = Category      }
 
    local lmodCmdA = {
       {cmd = 'add',          min = 2, action = loadTbl     },
       {cmd = 'avail',        min = 2, action = availTbl    },
+      {cmd = 'category',     min = 3, action = categoryTbl },
       {cmd = 'delete',       min = 3, action = unloadTbl   },
       {cmd = 'describe',     min = 3, action = mcTbl       },
       {cmd = 'disable',      min = 4, action = disableTbl  },
@@ -337,16 +341,20 @@ function main()
 
    dbg.set_prefix(colorize("red","Lmod"))
 
-   local shellNm = barefilename(arg[1])
-   if (BaseShell.isValid(shellNm)) then
+   -- Get shell name from 1st argument
+   local shellNm, success = dynamic_shell(arg[1])
+   if (success) then
       table.remove(arg,1)
    else
       shellNm = "bash"
    end
 
-   local masterTbl = masterTbl()
-   MCP = MasterControl.build("load")
-   mcp = MasterControl.build("load")
+   -- Build Shell object from shellNm
+   Shell = BaseShell:build(shellNm)
+
+   local optionTbl = optionTbl()
+   MCP = MainControl.build("load")
+   mcp = MainControl.build("load")
 
    ------------------------------------------------------------------
    -- initialize lmod with SitePackage and /etc/lmod/lmod_config.lua
@@ -354,14 +362,15 @@ function main()
 
    local cmdLineUsage = "Usage: module [options] sub-command [args ...]"
    Options:singleton(cmdLineUsage)
-   local userCmd = masterTbl.pargs[1]
-   table.remove(masterTbl.pargs,1)
+   local userCmd = optionTbl.pargs[1]
+   table.remove(optionTbl.pargs,1)
 
-   if (masterTbl.debug > 0 or masterTbl.dbglvl) then
+   if (getenv("LMOD_DEBUG") or optionTbl.debug > 0 or optionTbl.dbglvl) then
       local configuration = require("Configuration"):singleton()
+      io.stderr:setvbuf("no")
       io.stderr:write(configuration:report())
-      masterTbl.dbglvl = (type(masterTbl.dbglvl) == "number") and masterTbl.dbglvl or 1
-      local dbgLevel = max(masterTbl.debug, masterTbl.dbglvl or 1)
+      optionTbl.dbglvl = (type(optionTbl.dbglvl) == "number") and optionTbl.dbglvl or 1
+      local dbgLevel = max(optionTbl.debug, optionTbl.dbglvl or 1)
       dbg:activateDebug(dbgLevel)
    end
 
@@ -377,32 +386,24 @@ function main()
       dbg.print{"package.cpath: ",package.cpath,"\n"}
       dbg.print{"lmodPath: ", cosmic:value("LMOD_PACKAGE_PATH"),"\n"}
       dbg.print{"LOADEDMODULES: ",getenv("LOADEDMODULES"),"\n"}
+      dbg.print{"shellNm: ",shellNm,", Shell:name(): ",Shell:name(),"\n"}
    end
 
    -- dumpversion and quit if requested.
-   if (masterTbl.dumpversion) then
+   if (optionTbl.dumpversion) then
       io.stderr:write(Version.tag(),"\n")
       os.exit(0)
    end
 
-   -- Build Shell object from shellNm
-   Shell = BaseShell:build(shellNm)
-   dbg.print{"shellNm: ",shellNm,", Shell:name(): ",Shell:name(),"\n"}
 
    local tracing = cosmic:value("LMOD_TRACING")
    if (tracing == "yes" ) then
-      local a   = {}
-      a[#a + 1] = "Lmod version: "
-      a[#a + 1] = Version.name()
-      a[#a + 1] = "\n"
-      a[#a + 1] = "running: module "
-      a[#a + 1] = concatTbl(arg," ")
-      a[#a + 1] = "\n"
-      Shell:echo(concatTbl(a,""))
+      tracing_msg{"Lmod version: ", Version.name(), "\n",
+                  "running: module ", concatTbl(arg," ")}
    end
 
    -- gitversion and quit if requested.
-   if (masterTbl.gitversion) then
+   if (optionTbl.gitversion) then
       local gitV = Version.git()
       if (gitV == "") then
          gitV = Version.tag()
@@ -414,23 +415,33 @@ function main()
    end
 
    -- print version and quit if requested.
-   if (masterTbl.version) then
+   if (optionTbl.version) then
       io.stderr:write(version())
       os.exit(0)
    end
 
    -- print Configuration and quit.
-   if (masterTbl.config) then
+   if (optionTbl.config) then
       local configuration = require("Configuration"):singleton()
       local a = {}
       a[1] = version()
-      a[2] = configuration:report()
+      a[2] = configuration:report{mini=false}
+      pcall(pager,io.stderr,concatTbl(a,""))
+      os.exit(0)
+   end
+
+   -- print mini configuration and quit.
+   if (optionTbl.miniConfig) then
+      local configuration = require("Configuration"):singleton()
+      local a = {}
+      a[1] = version()
+      a[2] = configuration:report{mini=true}
       pcall(pager,io.stderr,concatTbl(a,""))
       os.exit(0)
    end
 
    -- dump Configuration in json and quit.
-   if (masterTbl.configjson) then
+   if (optionTbl.configjson) then
       local configuration = require("Configuration"):singleton()
       local a = {}
       a[#a+1] = configuration:report_json()
@@ -458,12 +469,12 @@ function main()
    hook.apply("startup", cmdName)
 
    local checkMPATH = (cmdT) and cmdT.checkMPATH or false
-   dbg.print{"Calling Master:singleton(checkMPATH) w checkMPATH: ",checkMPATH,"\n"}
-   master = Master:singleton(checkMPATH)
+   dbg.print{"Calling Hub:singleton(checkMPATH) w checkMPATH: ",checkMPATH,"\n"}
+   hub = Hub:singleton(checkMPATH)
 
-   if (masterTbl.checkSyntax) then
-      MCP = MasterControl.build("checkSyntax")
-      mcp = MasterControl.build("checkSyntax")
+   if (optionTbl.checkSyntax) then
+      MCP = MainControl.build("checkSyntax")
+      mcp = MainControl.build("checkSyntax")
       setSyntaxMode(true)
       Shell:setActive(false)
    end
@@ -472,13 +483,13 @@ function main()
    --Shell:expand(varTbl)
 
    -- if Help was requested then quit.
-   if (masterTbl.cmdHelp) then
+   if (optionTbl.cmdHelp) then
       Help()
       os.exit(0)
    end
 
    -- Report ModuleTable if requested and exit.
-   if (masterTbl.reportMT) then
+   if (optionTbl.reportMT) then
       local mt = FrameStk:singleton():mt()
       io.stderr:write(mt:serializeTbl("pretty"),"\n")
       os.exit(0)
@@ -500,7 +511,7 @@ function main()
 
    local cmd  = cmdT.cmd
    dbg.print{"cmd name: ", cmdT.name,"\n"}
-   cmd(unpack(masterTbl.pargs))
+   cmd(unpack(optionTbl.pargs))
 
    ------------------------------------------------------------
    -- After running command reset frameStk and mt as the
@@ -555,13 +566,14 @@ function main()
    -- Output all newly created path and variables.
    Shell:expand(varT)
 
+   -- Expand any execute\{\} cmds
    if (Shell:real_shell())then
       Exec:exec():expand()
    end
 
    local t2 = epoch()
    timer:deltaT("main", t2 - t1)
-   if (masterTbl.reportTimer) then
+   if (optionTbl.reportTimer) then
       io.stderr:write(timer:report(),"\n")
    end
 
