@@ -89,6 +89,13 @@ cosmic:init{name    = "SITE_CONTROLLED_PREFIX",
             no_env  = true,
             default = "no"}
 
+------------------------------------------------------------------------
+-- LMOD_USE_DOT_CONFIG_ONLY: only write to ~/.config/lmod for collections
+------------------------------------------------------------------------
+cosmic:init{name    = "LMOD_USE_DOT_CONFIG_ONLY",
+            sedV    = "@lmod_use_dot_config_only@",
+            default = "no"}
+
 ------------------------------------------------------------------------
 -- ModulePath: The name of the environment variable which contains the
 --             directories that contain modulefiles.
@@ -96,13 +103,6 @@ cosmic:init{name    = "SITE_CONTROLLED_PREFIX",
 
 ModulePath  = "MODULEPATH"
 
-------------------------------------------------------------------------
--- LMODdir:     The directory where the cache file, default files
---              and module table state files go.
-------------------------------------------------------------------------
-
-LMODdir     = ".lmod.d"
-
 ------------------------------------------------------------------------
 -- LMOD_CACHE_VERSION:    The current version for the Cache file
 ------------------------------------------------------------------------
@@ -123,6 +123,14 @@ cosmic:init{name    = "LMOD_TRACING",
             yn      = "no"}
 
 
+------------------------------------------------------------------------
+-- LMOD_DYNAMIC_SPIDER_CACHE :  Support for Dynamic Spider Caches
+------------------------------------------------------------------------
+
+cosmic:init{name = "LMOD_DYNAMIC_SPIDER_CACHE",
+            sedV = "@dynamic_spider_cache@",
+            yn   = "yes"}
+
 ------------------------------------------------------------------------
 -- LMOD_CASE_INDEPENDENT_SORTING :  make avail and spider use case
 --                                  independent sorting.
@@ -153,14 +161,41 @@ cosmic:init{name = "LMOD_REDIRECT",
 local rcfiles = getenv("LMOD_RC")
 cosmic:init{name    = "LMOD_RC",
             default = "",
+            envV    = rcfiles,
             assignV = rcfiles}
 
 ------------------------------------------------------------------------
--- LMOD_FAST_TCL_INTERP:  Send messages to stdout instead of stderr
+-- LMOD_FAST_TCL_INTERP:  Build and use the tcl library as part of Lmod
 ------------------------------------------------------------------------
 cosmic:init{name = "LMOD_FAST_TCL_INTERP",
             sedV = "@fast_tcl_interp@",
-            yn   = "no"}
+            yn   = "yes"}
+
+------------------------------------------------------------------------
+-- LMOD_USING_FAST_TCL_INTERP:  Is the fast TCL interp active
+------------------------------------------------------------------------
+cosmic:init{name    = "LMOD_USING_FAST_TCL_INTERP",
+            yn      = "yes",
+            default = "yes"}
+
+------------------------------------------------------------------------
+-- LMOD_SITEPACKAGE_LOCATION:  SitePackage.lua location
+------------------------------------------------------------------------
+local sitePkgLoc = "@LMOD_TOP_DIR@/libexec/SitePackage.lua"
+if (sitePkgLoc:sub(1,1) == "@") then
+   sitePkgLoc = "<srctree>"
+end
+
+
+cosmic:init{name    = "LMOD_SITEPACKAGE_LOCATION",
+            default = sitePkgLoc}
+
+
+------------------------------------------------------------------------
+-- LMOD_CFG:  lmod_config.lua locatoin
+------------------------------------------------------------------------
+cosmic:init{name    = "LMOD_CONFIG_LOCATION",
+            default = "no"}
 
 ------------------------------------------------------------------------
 -- LMOD_SITE_NAME: The site name (e.g. TACC)
@@ -327,6 +362,17 @@ cosmic:init{name    = "LMOD_PAGER",
 cosmic:init{name    = "LMOD_PAGER_OPTS",
             default = "-XqMREF"}
 
+------------------------------------------------------------------------
+-- LMOD_SYSTEM_DEFAULT_MODULES: 
+------------------------------------------------------------------------
+local defaultModules = getenv("LMOD_SYSTEM_DEFAULT_MODULES")
+
+cosmic:init{name    = "LMOD_SYSTEM_DEFAULT_MODULES",
+            envV    = defaultModules,
+            assignV = defaultModules or "",
+            default = "__unknown__" }
+
+
 ------------------------------------------------------------------------
 -- LMOD_MODULERCFILE: The system RC file to specify aliases, defaults
 --                    and hidden modules.
@@ -338,9 +384,10 @@ local rc_dflt    = pathJoin(etcDir,"rc.lua")
 if (not isFile(rc_dflt)) then
    rc_dflt   = pathJoin(etcDir,"rc")
 end
-local rc        = getenv("LMOD_MODULERCFILE") or getenv("MODULERCFILE") or rc_dflt
+local rc        = getenv("LMOD_MODULERCFILE") or getenv("MODULERCFILE")
 cosmic:init{name    = "LMOD_MODULERCFILE",
             default = rc_dflt,
+            envV    = rc,
             assignV = rc,
             kind    = "file"}
 
@@ -372,11 +419,11 @@ LMOD_RTM_TESTING = getenv("LMOD_RTM_TESTING")
 -- LMOD_ADMIN_FILE: The Nag file.
 ------------------------------------------------------------------------
 local lmod_nag_default = pathJoin(etcDir,"admin.list")
-local lmod_nag         = getenv("LMOD_ADMIN_FILE") or lmod_nag_default
+local lmod_nag         = getenv("LMOD_ADMIN_FILE")
 cosmic:init{name    = "LMOD_ADMIN_FILE",
             default = lmod_nag_default,
-            assignV = lmod_nag,
-            kind    = "file"}
+            envV    = lmod_nag,
+            assignV = lmod_nag}
 
 ------------------------------------------------------------------------
 -- LMOD_AVAIL_STYLE: Used by the avail hook to control how avail output
@@ -387,12 +434,10 @@ cosmic:init{name    = "LMOD_ADMIN_FILE",
 --                   entry is the default (i.e. A:B:C => A is default).
 ------------------------------------------------------------------------
 
-local style = getenv("LMOD_AVAIL_STYLE") or "<system>"
-if (style == "") then
-   style = "<system>"
-end
+local style = getenv("LMOD_AVAIL_STYLE")
 cosmic:init{name    = "LMOD_AVAIL_STYLE",
             default = "<system>",
+            envV    = style,
             assignV = style}
 
 ------------------------------------------------------------------------
@@ -401,6 +446,7 @@ cosmic:init{name    = "LMOD_AVAIL_STYLE",
 
 cosmic:init{name    = "LFS_VERSION",
             default = "1.6.3",
+            kind    = "D",
             assignV = lfs._VERSION:gsub("LuaFileSystem  *","")}
 
 ------------------------------------------------------------------------
@@ -411,7 +457,7 @@ cosmic:init{name    = "LFS_VERSION",
 --
 
 ------------------------------------------------------------------------
--- MCP, mcp:  Master Control Program objects.  These objects implement
+-- MCP, mcp:  MainControl Program objects.  These objects implement
 --            the module functions: load, setenv, prepend_path, etc.
 --            MCP is always positive.  That is, load is load, setenv is
 --            setenv.  Where as mcp is dynamic.  It is positive on load
@@ -478,6 +524,7 @@ end
 
 cosmic:init{name    = "LMOD_LD_LIBRARY_PATH",
             default = false,
+            envV    = ld_lib_path,
             assignV = ld_lib_path}
 
 ------------------------------------------------------------------------
@@ -494,6 +541,7 @@ end
 
 cosmic:init{name    = "LMOD_LD_PRELOAD",
             default = false,
+            envV    = ld_preload,
             assignV = ld_preload}
 
 ------------------------------------------------------------------------
@@ -529,9 +577,17 @@ cosmic:init{name    = "LMOD_OVERRIDE_LANG",
             sedV    = "@lang@",
             default = false}
 
-local lang = (cosmic:value("LMOD_OVERRIDE_LANG") or getenv("LANG") or "en"):gsub("_.*","")
+local langEnv = getenv("LMOD_LANG") or getenv("LANG")
+if (langEnv) then
+   langEnv = langEnv:gsub("_.*","")
+end
+
+local lang = cosmic:value("LMOD_OVERRIDE_LANG") or langEnv
+
 cosmic:init{name    = "LMOD_LANG",
             default = "en",
+            sedV    = "@lang@",
+            envV    = langEnv,
             assignV = lang}
 
 ------------------------------------------------------------------------
@@ -547,9 +603,13 @@ cosmic:init{name = "LMOD_SETTARG_FULL_SUPPORT",
 -- LMOD_ANCIENT_TIME:  the time in seconds when the cache file is considered old
 ------------------------------------------------------------------------
 local ancient_dflt  = 86400
-local ancient       = tonumber(getenv("LMOD_ANCIENT_TIME")) or tonumber("@ancient@") or ancient_dflt
+local ancientEnv    = getenv("LMOD_ANCIENT_TIME")
+local ancientSedV   = "@ancient@"
+local ancient       = tonumber(ancientEnv) or tonumber(ancientSedV)
 cosmic:init{name    = "LMOD_ANCIENT_TIME",
             default = ancient_dflt,
+            envV    = ancientEnv,
+            sedV    = ancientSedV,
             assignV = ancient}
 ancient             = cosmic:value("LMOD_ANCIENT_TIME")
 
@@ -559,18 +619,25 @@ ancient             = cosmic:value("LMOD_ANCIENT_TIME")
 ------------------------------------------------------------------------
 
 local shortTime_dflt = 2
-local shortTime      = tonumber(getenv("LMOD_SHORT_TIME")) or tonumber("@short_time@") or shortTime_dflt
+local shortTimeEnv   = getenv("LMOD_SHORT_TIME")
+local shortTimeSedV  = "@short_time@"
+local shortTime      = tonumber(shortTimeEnv) or tonumber(shortTimeSedV)
 cosmic:init{name     = "LMOD_SHORT_TIME",
             default  = shortTime_dflt,
+            envV     = shortTimeEnv,
+            sedV     = shortTimeSedV,
             assignV  = shortTime}
 
 ------------------------------------------------------------------------
 -- Threshold:  The amount of time to wait before printing the cache
 --             rebuild message.  (It has to be 1 second or greater).
 ------------------------------------------------------------------------
-local threshold      = tonumber(getenv("LMOD_THRESHOLD")) or 1
+local threshold_dflt = 1
+local thresholdEnv   = getenv("LMOD_THRESHOLD")
+local threshold      = tonumber(thresholdEnv)
 cosmic:init{name     = "LMOD_THRESHOLD",
-            default  = 1,
+            default  = threshold_dflt,
+            envV     = thresholdEnv,
             assignV  = threshold}
 
 
@@ -580,17 +647,6 @@ cosmic:init{name     = "LMOD_THRESHOLD",
 ------------------------------------------------------------------------
 shortLifeCache = ancient/12
 
-
-------------------------------------------------------------------------
--- LMOD_USE_DOT_FILES: Use ~/.lmod.d/.cache or ~/.lmod.d/__cache__
-------------------------------------------------------------------------
-
-cosmic:init{name = "LMOD_USE_DOT_FILES",
-            sedV = "@use_dot_files@",
-            yn   = "yes"}
-
-local use_dot_files = cosmic:value("LMOD_USE_DOT_FILES")
-
 ------------------------------------------------------------------------
 -- LMOD_ALLOW_ROOT_USE
 ------------------------------------------------------------------------
@@ -618,7 +674,7 @@ cosmic:init{name    = "MODULEPATH_ROOT",
 local HashSum      = "@hashsum@"
 local found        = false
 if (HashSum:sub(1,1) == "@") then
-   local a = { "sha1sum", "shasum", "md5sum", "md5" }
+   local a = { "gsha1sum", "sha1sum", "shasum", "md5sum", "md5" }
    for i = 1,#a do
       HashSum, found = findInPath(a[i])
       if (found) then break end
@@ -642,8 +698,7 @@ cosmic:init{name    = "PATH_TO_LUA",
 ------------------------------------------------------------------------
 -- usrCacheDir: user cache directory
 ------------------------------------------------------------------------
-USER_CACHE_DIR_NAME  = ( use_dot_files == "yes" ) and ".cache" or "__cache__"
-usrCacheDir          = pathJoin(getenv("HOME"),".lmod.d",USER_CACHE_DIR_NAME)
+usrCacheDir          = pathJoin(getenv("HOME"),".cache/lmod")
 
 ------------------------------------------------------------------------
 -- updateSystemFn: The system file that is touched everytime the system
@@ -725,10 +780,10 @@ FullName        = false
 Shell          = false
 
 ------------------------------------------------------------------------
--- master:
+-- hub:
 ------------------------------------------------------------------------
 
-master         = false
+hub         = false
 
 TraceCounter   = 0
 ReloadAllCntr  = 0
