@@ -36,11 +36,15 @@
 
 global g_loadT g_varsT g_fullName g_usrName g_shellName g_mode g_shellType g_outputA, g_fast
 global g_moduleT g_setup_moduleT g_lua_cmd env g_my_cmd
+global g_envT g_envClrT
 
 set g_setup_moduleT 0
 set g_lua_cmd       "@path_to_lua@"
 set g_lmod_cmd      "@path_to_lmod@"
 set g_my_cmd        $argv0
+set g_envT          [dict create]
+set g_envClrT       [dict create]
+
 namespace eval ::cmdline {
     namespace export getArgv0 getopt getKnownOpt getfiles getoptions \
 	    getKnownOptions usage
@@ -436,14 +440,8 @@ proc module-whatis { args } {
     lappend g_outputA  "whatis(\[===\[$msg2\]===\])\n"
 }
 
-proc myBreak { args } {
-    set msg ""
-    foreach item $args {
-       append msg $item
-       append msg " "
-    }
-    set msg [string trimright $msg]
-    cmdargs "LmodBreak" $msg
+proc myBreak {  } {
+    cmdargs "LmodBreak"  ""
 }
 
 
@@ -461,9 +459,12 @@ proc setenv { var val args } {
     if {$mode == "load"} {
 	# set env vars in the current environment during load only
 	# Don't unset then during remove mode.
-	set env($var)     $val
+	set-env $var $val
 	set g_varsT($var) $val
     }
+    if {$mode == "display"} {
+	set-env $var $val
+    }
     cmdargs "setenv" $var $val
 }
 
@@ -478,7 +479,7 @@ proc unsetenv { var {val {}}} {
     }\
     elseif {$mode == "remove"} {
 	if {$val != ""} {
-	    set env($var) $val
+	    set-env $var $val
 	}
     }
     cmdargs "unsetenv" $var $val
@@ -488,7 +489,10 @@ proc require-fullname {} {
     cmdargs "requireFullName"
 }
 
-
+proc haveDynamicMPATH {} {
+    cmdargs "haveDynamicMPATH"
+}
+    
 # Dictionary-style string comparison
 # Use dictionary sort of lsort proc to compare two strings in the "string
 # compare" fashion (returning -1, 0 or 1). Tcl dictionary-style comparison
@@ -508,7 +512,7 @@ proc versioncmp {str1 str2} {
 
 proc pushenv { var val } {
     global env  g_varsT
-    set env($var) $val
+    set-env $var $val
     set g_varsT($var) $val
     cmdargs "pushenv" $var $val
 }
@@ -986,6 +990,7 @@ proc execute-modulefile {modfile } {
     interp alias $child exit     	 {} my_exit
     interp alias $child extensions     	 {} extensions
     interp alias $child family         	 {} family
+    interp alias $child haveDynamicMPATH {} haveDynamicMPATH
     interp alias $child initGA         	 {} initGA
     interp alias $child is-loaded      	 {} is-loaded
     interp alias $child is-avail      	 {} is-avail
@@ -1070,6 +1075,27 @@ proc unset-env {var} {
 	unset env($var)
     }
 }
+proc set-env {var value} {
+    global g_envT g_envClrT env
+    # If setting a var not seen then mark it for deletion when reset is called.
+    if { ! [info exists env($var)] && ! [info exists g_envT($var)] } {
+	dict set g_envClrT $var 1
+    } else {
+	dict set g_envT $var $env($var)
+    }
+    set env($var) $value
+}
+
+proc reset-env {} {
+    global env g_envT g_envClrT
+    dict for {key value} $g_envT {
+	set env($key) $value
+    }
+    dict for {key value} $g_envClrT {
+	unset env($key)
+    }
+}
+
 
 proc main { modfile } {
     global g_mode
@@ -1077,6 +1103,7 @@ proc main { modfile } {
     pushMode           $g_mode
     execute-modulefile $modfile
     popMode
+    reset-env
 }
 
 global g_loadT g_help 
