@@ -63,7 +63,8 @@ local readlink     = posix.readlink
 local setenv_posix = posix.setenv
 local stat         = posix.stat
 local strfmt       = string.format
-
+local s_envT       = {}
+local s_clrEnvT    = {}
 --------------------------------------------------------------------------
 -- This is 5.1 Lua function to cover the table.pack function
 -- that is in Lua 5.2 and later.
@@ -82,6 +83,16 @@ function __LINE__()
 end
 
 
+local function l_prequire(m)
+   local ok, value = pcall(require, m) 
+   if (not ok) then 
+      return nil, value
+   end
+  return value
+end
+
+
+
 --------------------------------------------------------------------------
 -- Generate a message that will fix the available terminal width.
 -- @param width The terminal width
@@ -430,16 +441,19 @@ function getMT()
    local mtSz  = tonumber(getenv(SzStr)) or huge
    local s     = false
 
+   dbg.print{"getMT: Sz: ",mtSz,"\n"}
    for i = 1, mtSz do
       local envNm = strfmt(piece,i)
       local v     = getenv(envNm)
       if (v == nil) then break end
+      dbg.print{"getMT: nm:",envNm,", v: ",v,"\n"}
+
       a[#a+1]    = v
    end
    if (#a > 0) then
       s = decode64(concatTbl(a,""))
    end
-   dbg.print{"getMT s: ",s,"\n"}
+   --dbg.print{"getMT s: ",s,"\n"}
    return s
 end
 
@@ -503,13 +517,14 @@ function length(s)
 end
 
 
-local s_masterTbl = {}
+local s_optionTbl = {}
 --------------------------------------------------------------------------
--- Manage the Master Hash Table.
-function masterTbl()
-   return s_masterTbl
+-- Manage the Hub Hash Table.
+function optionTbl()
+   return s_optionTbl
 end
 
+masterTbl = optionTbl
 
 function paired2pathT(path)
    if (not path) then
@@ -558,10 +573,12 @@ function path2pathA(path, delim, clearDoubleSlash)
       return {}
    end
    if (path == '') then
-      return { ' ' }
+      return { '' }
    end
+   local delimPatt = delim .. "+";
 
-   local is, ie
+
+   path = path:gsub(delimPatt,delim)
 
    local pathA = {}
    for v  in path:split(delim) do
@@ -601,6 +618,9 @@ function regular_cmp(x,y)
 end
 
 
+
+
+
 function sanizatizeTbl(rplmntA, inT, outT)
    for k, v in pairs(inT) do
       local key = k
@@ -822,6 +842,7 @@ end
 --------------------------------------------------------------------------
 -- Set warning flags to true.
 function setWarningFlag()
+   dbg.print{"setting warning flag\n"}
    s_warning = true
 end
 
@@ -831,13 +852,44 @@ function getWarningFlag()
    return s_warning
 end
 
+local function l_restoreEnv(oldEnvT, newEnvT)
+   dbg.start{"l_restoreEnv(oldEnvT, newEnvT)"}
+   local envT = {}
+   for k,v in newEnvT do
+      local old = origEnvT[k]
+      if (old == nil) then
+         envT[k] = false
+      elseif (v ~= old) then
+         envT[k] = v
+      end
+      origEnvT[k] = nil
+   end
+
+   for k,v in origEnvT do
+      local new = newEnvT[k]
+      if (new == nil) then
+         envT[k] = v
+      end
+   end
+
+   dbg.printT("envT",envT)
+   for k,v in envT do
+      setenv_posix(k,v or nil, true)
+   end
+   dbg.fini("l_restoreEnv")
+end   
+
+
 local function l_runTCLprog(TCLprog, tcl_args)
-   local a   = {}
-   a[#a + 1] = cosmic:value("LMOD_TCLSH")
-   a[#a + 1] = TCLprog
-   a[#a + 1] = tcl_args or ""
-   local cmd = concatTbl(a," ")
+   local a        = {}
+   local origEnvT = posix.getenv()
+   a[#a + 1]      = cosmic:value("LMOD_TCLSH")
+   a[#a + 1]      = TCLprog
+   a[#a + 1]      = tcl_args or ""
+   local cmd      = concatTbl(a," ")
    local whole, status = capture(cmd)
+   local newEnvT  = posix.getenv()
+
    return whole, status
 end
 
@@ -853,10 +905,19 @@ local function l_build_runTCLprog()
    if (fast_tcl_interp == "no") then
       _G.runTCLprog = l_runTCLprog
    else
-      _G.runTCLprog = require("tcl2lua").runTCLprog
+      local m = l_prequire("tcl2lua")
+      if (not m) then
+         _G.runTCLprog = l_runTCLprog
+      else
+         _G.runTCLprog = m.runTCLprog
+      end
    end
 end
 
+function usingFastTCLInterp()
+   return (_G.runTCLprog ~= l_runTCLprog) and "yes" or "no"
+end
+
 --------------------------------------------------------------------------
 -- Create the accept functions to allow or ignore TCL modulefiles.
 local function l_build_accept_function()
@@ -963,6 +1024,30 @@ local function l_build_quarantineT()
    end
 end
 
+------------------------------------------------------------
+-- Save changes to env when processing spider cache
+function save_set_env(name, value)
+   local oldV = getenv(name)
+   if (not  oldV and not s_envT[name]) then
+      s_clrEnvT[name] = true
+   else
+      s_envT[name] = oldV
+   end
+   posix.setenv(name, value, true)
+end
+
+function reset_env()
+   local setenv_posix = posix.setenv
+   for k, v in pairs(s_envT) do
+      setenv_posix(k, v, true)
+   end
+   for k in pairs(s_clrEnvT) do
+      setenv_posix(k, nil, true)
+   end
+   s_clrEnvT = {}
+   s_envT    = {}
+end
+      
 ------------------------------------------------------------
 -- Initialize Lmod 
 
@@ -974,6 +1059,7 @@ function initialize_lmod()
    --  The StandardPackage is where Lmod registers hooks.  Sites may
    --  override the hook functions in SitePackage.
    ------------------------------------------------------------------------
+   cosmic:set_key("StdPkg")
    require("StandardPackage")
 
    ------------------------------------------------------------------------
@@ -984,8 +1070,10 @@ function initialize_lmod()
    local fn        = pathJoin(configDir,"lmod_config.lua")
    if (isFile(fn)) then
       assert(loadfile(fn))()
+      cosmic:assign("LMOD_CONFIG_LOCATION",fn)
    end
 
+   cosmic:set_key("lmod_cfg")
    build_i18n_messages()
    l_build_runTCLprog()
    l_build_accept_function()   
@@ -1007,5 +1095,85 @@ function initialize_lmod()
                       package.cpath
    end
 
+   local locSitePkg = locatePkg("SitePackage")
+   cosmic:assign("LMOD_SITEPACKAGE_LOCATION",locSitePkg)
+   cosmic:set_key("SitePkg")
    require("SitePackage")
+   cosmic:set_key("Other")
 end
+
+function tracing_msg(msgA)
+   local FrameStk   = require("FrameStk")
+   local shell      = _G.Shell
+   local stackDepth = FrameStk:singleton():stackDepth()
+   local indent     = ("  "):rep(stackDepth+1)
+   local b          = {}
+   b[#b + 1]        = indent
+   for i = 1,#msgA do
+      b[#b+1] = msgA[i]
+   end
+   b[#b + 1]        = "\n"
+   shell:echo(concatTbl(b,""))
+end
+
+function dynamic_shell(shellNm)
+   local BaseShell = require("BaseShell") 
+   local success   = false
+   
+   if (shellNm ~= "shell") then
+      if (BaseShell.isValid(shellNm)) then
+         -- Trust a valid shell and report the shell name is valid and return
+         success = true
+         return shellNm, success
+      end
+   else
+      -- If here then the name of the shell is "shell" and it is "valid"
+      success = true
+   end
+
+   ------------------------------------------------------------
+   -- Dynamically find the shell from the parent process
+   local ppid  = posix.getpid("ppid")
+   local n     = shellNm
+   local fn    = "/proc/"..ppid.."/exe"
+   local found = false
+   if (isFile(fn)) then
+      n = posix.readlink(fn)
+      if (not n) then
+         local cmd = "readlink "..fn
+         n = capture(cmd):gsub("%s+$","")
+      end
+      n = barefilename(n)
+      if (BaseShell.isValid(n)) then
+         shellNm = n
+         return shellNm, success
+      end
+   end
+   
+   local ps_cmd = "@ps@"
+   if ( ps_cmd:sub(1,1) == "@" ) then
+      ps_cmd = "ps"
+   end
+   local cmd = ps_cmd.." -p "..ppid.." -ocomm="
+   n         = capture(cmd):gsub("^%-",""):gsub("%s+$","")
+   n         = barefilename(n)
+   if (BaseShell.isValid(n)) then
+      shellNm = n
+   else
+      shellNm = "bash"  -- If "n" is not a valid shell assume bash.
+   end
+   return shellNm, success
+end
+
+function locatePkg(pkg)
+   local result = nil
+   for path in package.path:split(";") do
+      local s = path:gsub("?",pkg)
+      if (isFile(s)) then
+         result = abspath(s)
+         break
+      end
+   end
+   return result
+end
+
